Class: Kube::Cluster::Standard::ESO::ExternalSecret::KeyRef

Inherits:
Struct
  • Object
show all
Defined in:
lib/kube/cluster/standard/eso/external_secret.rb

Overview

Returned by .key — carries the secret ref and key name. When the volume_mounts hash is processed, this tells the volume processing layer to mount a single key from the secret as a file.

Instance Attribute Summary collapse

Instance Attribute Details

#key_nameObject

Returns the value of attribute key_name

Returns:

  • (Object)

    the current value of key_name



19
20
21
# File 'lib/kube/cluster/standard/eso/external_secret.rb', line 19

def key_name
  @key_name
end

#secretObject

Returns the value of attribute secret

Returns:

  • (Object)

    the current value of secret



19
20
21
# File 'lib/kube/cluster/standard/eso/external_secret.rb', line 19

def secret
  @secret
end