Class: Kube::Cluster::Standard::ESO::ExternalSecret::TemplateRef
- Inherits:
-
Struct
- Object
- Struct
- Kube::Cluster::Standard::ESO::ExternalSecret::TemplateRef
- Defined in:
- lib/kube/cluster/standard/eso/external_secret.rb
Overview
Returned by .template — carries the secret ref and template value. When the env hash is processed, the key becomes both the env var name and the secret template data key.
Instance Attribute Summary collapse
-
#secret ⇒ Object
Returns the value of attribute secret.
-
#template_value ⇒ Object
Returns the value of attribute template_value.
Instance Attribute Details
#secret ⇒ Object
Returns the value of attribute secret
14 15 16 |
# File 'lib/kube/cluster/standard/eso/external_secret.rb', line 14 def secret @secret end |
#template_value ⇒ Object
Returns the value of attribute template_value
14 15 16 |
# File 'lib/kube/cluster/standard/eso/external_secret.rb', line 14 def template_value @template_value end |