Class: Kube::Cluster::Standard::VictoriaMetrics::VMScrapeConfig
- Inherits:
-
Object
- Object
- Kube::Cluster::Standard::VictoriaMetrics::VMScrapeConfig
- Defined in:
- lib/kube/cluster/standard/victoria_metrics/vm_scrape_config.rb
Overview
Generic scrape configuration supporting the full range of service- discovery mechanisms (static, kubernetes, http, ec2, consul, …). Declare the discovery configs and relabelling in the block.
Instance Method Summary collapse
-
#initialize(name:, &block) ⇒ VMScrapeConfig
constructor
A new instance of VMScrapeConfig.
Constructor Details
#initialize(name:, &block) ⇒ VMScrapeConfig
Returns a new instance of VMScrapeConfig.
14 15 16 17 18 19 |
# File 'lib/kube/cluster/standard/victoria_metrics/vm_scrape_config.rb', line 14 def initialize(name:, &block) super() { .name = name instance_exec(&block) if block } end |